library(foreign)
library(mgcv)

jacob <- read.dta(file.choose())

attach(jacob)

#Additive Model
gam.1 <- gam(chal_vote ~ s(perotvote, bs="cr") + s(checks_raw, bs="cr"), data=jacob)
summary(gam.1)


#Plot Effects Together
par(mfrow = c(1,2))
plot(gam.1, select=1, rug=FALSE, se=TRUE, ylab="Challengers' Vote Share (%)", xlab="Vote for Perot (%)", residual=FALSE, bty="l", shift=36.6672)
points(perotvote, chal_vote, pch=".", cex=1.75)

plot(gam.1, select=2, rug=FALSE, se=TRUE, ylab="Challengers' Vote Share (%)", xlab="Number of Overdrafts", residual=FALSE, bty="l", shift=36.6672)
points(checks_raw, chal_vote, pch=".", cex=2)

#Statistical inference
#OLS Model
ols.1 <- gam(chal_vote ~ perotvote + checks_raw, data=jacob)

#Automatic Test
anova(ols.1, gam.1, test="Chisq")

#A Second Test
#Test against log transformation
gam.2 <- gam(chal_vote ~ s(perotvote, bs="cr") + logchecks1, data=jacob)

#Compare Fits
anova(gam.2, gam.1, test="Chisq")

######################################################################
# Semiparametric Regression Models
######################################################################

#Baseline Model
ols <- gam(chal_vote ~ exp_chal + chal_spend + inc_spend + pres_vote + checks_raw + 
          marginal + partisan_redist + perotvote, data=jacob) 
       
                    
#Test Each Continuous Covariate

gam.1 <- gam(chal_vote ~ exp_chal + s(chal_spend, bs="cr") + inc_spend + pres_vote + checks_raw + marginal + partisan_redist + perotvote, data=jacob) 
anova(ols, gam.1, test="Chisq")

gam.2 <- gam(chal_vote ~ exp_chal + chal_spend + s(inc_spend, bs="cr") + pres_vote + checks_raw + marginal + partisan_redist + perotvote, data=cong)
anova(ols, gam.2, test="Chisq")

gam.3 <- gam(chal_vote ~ exp_chal + chal_spend + inc_spend + s(pres_vote, bs="cr") + checks_raw + marginal + partisan_redist + perotvote, data=jacob)
anova(ols, gam.3, test="Chisq")

gam.4 <- gam(chal_vote ~ exp_chal + chal_spend + inc_spend + pres_vote + s(checks_raw, bs="cr") + marginal + partisan_redist + perotvote, data=cong)
anova(ols, gam.4, test="Chisq")

gam.5 <- gam(chal_vote ~ exp_chal + chal_spend + inc_spend + pres_vote + checks_raw + marginal + partisan_redist + s(perotvote, bs="cr"), data=jacob)   
anova(ols, gam.5, test="Chisq")

#Now Against Logged Fits
olsl.1 <- gam(chal_vote ~ exp_chal + log(chal_spend) + inc_spend + pres_vote + checks_raw + 
          marginal + partisan_redist + perotvote, data=cong) 

olsl.2 <- gam(chal_vote ~ exp_chal + chal_spend + log(inc_spend) + pres_vote + checks_raw + 
          marginal + partisan_redist + perotvote, data=jacob) 
     
olsl.3 <- gam(chal_vote ~ exp_chal + chal_spend + inc_spend + log(pres_vote) + checks_raw + 
          marginal + partisan_redist + perotvote, data=jacob)     

olsl.4 <- gam(chal_vote ~ exp_chal + chal_spend + inc_spend + pres_vote + logchecks1 + 
          marginal + partisan_redist + perotvote, data=jacob)  

olsl.5 <- gam(chal_vote ~ exp_chal + chal_spend + inc_spend + pres_vote + checks_raw + 
          marginal + partisan_redist + log_perot, data=jacob)           
          
anova(olsl.1, gam.1, test="Chisq")
anova(olsl.2, gam.2, test="Chisq")
anova(olsl.3, gam.3, test="Chisq")
anova(olsl.4, gam.4, test="Chisq")
anova(olsl.5, gam.5, test="Chisq")

gam.6 <- gam(chal_vote ~ exp_chal + s(chal_spend, bs="cr") + s(inc_spend, bs="cr") + s(pres_vote, bs= "cr") + logchecks1 + marginal + partisan_redist + s(perotvote, bs="cr"), data=jacob)

par(mfrow = c(2,2))
plot(gam.6, select=1, rug=FALSE, se=TRUE, ylab="Challengers' Vote Share (%)", xlab="Challenger Spending", residual=FALSE, bty="l", shift=33.02)
points(chal_spend, chal_vote, pch=".", cex=1.75)

plot(gam.6, select=2, rug=FALSE, se=TRUE, ylab="Challengers' Vote Share (%)", xlab="Incumbent Spending", residual=FALSE, bty="l", shift=33.02)
points(inc_spend, chal_vote, pch=".", cex=1.75)

plot(gam.6, select=3, rug=FALSE, se=TRUE, ylab="Challengers' Vote Share (%)", xlab="Challenger's Party Pres. Vote", residual=FALSE, bty="l", shift=33.02)
points(pres_vote, chal_vote, pch=".", cex=1.75)

plot(gam.6, select=4, rug=FALSE, se=TRUE, ylab="Challengers' Vote Share (%)", xlab="Vote for Perot (%)", residual=FALSE, bty="l", shift=33.02)
points(perotvote, chal_vote, pch=".", cex=1.75)



